<?php
/**
* Plugin 6.0 Class
*/
class WCP_Photo_Book_Gallery
{
	
	function __construct()
	{
		add_action( 'admin_enqueue_scripts', array($this, 'loading_scripts_admin'));
		add_action( 'init', array($this, 'wcp_register_books') );
		add_action( 'add_meta_boxes', array($this, 'books_data_boxes') );
		add_action( 'save_post', array($this, 'saving_photo_book_galleries') );

        add_filter('manage_photo_book_posts_columns', array($this, 'photo_book_column_head'));
        add_action('manage_photo_book_posts_custom_column', array($this, 'photo_book_column_content'), 10, 2);		

        add_shortcode( 'photo-book-gallery', array($this, 'render_photo_book_gallery') );
	}

    /**
    * Registers a new post type
    * @uses $wp_post_types Inserts new post type object into the list
    *
    * @param string  Post type key, must not exceed 20 characters
    * @param array|string  See optional args description above.
    * @return object|WP_Error the registered post type object, or an error object
    */
    function wcp_register_books() {
    
        $custom_labels = array(
            'name'                => __( 'Photo Books', 'photo-book-gallery' ),
            'singular_name'       => __( 'Photo Book', 'photo-book-gallery' ),
            'add_new'             => _x( 'Add New Book', 'photo-book-gallery', 'photo-book-gallery' ),
            'add_new_item'        => __( 'Add New Book', 'photo-book-gallery' ),
            'edit_item'           => __( 'Edit Book', 'photo-book-gallery' ),
            'new_item'            => __( 'New Book', 'photo-book-gallery' ),
            'view_item'           => __( 'View Photo Book', 'photo-book-gallery' ),
            'search_items'        => __( 'Search Books', 'photo-book-gallery' ),
            'not_found'           => __( 'No Photo Books found', 'photo-book-gallery' ),
            'not_found_in_trash'  => __( 'No Photo Books found in Trash', 'photo-book-gallery' ),
            'parent_item_colon'   => __( 'Parent Book:', 'photo-book-gallery' ),
            'menu_name'           => __( 'Photo Books', 'photo-book-gallery' ),
        );
    
        $anim_args = array(
            'labels'              => $custom_labels,
            'hierarchical'        => false,
            'description'         => 'Photo Books',
            'public'              => false,
            'show_ui'             => true,
            'show_in_menu'        => true,
            'show_in_admin_bar'   => true,
            'menu_position'       => null,
            'menu_icon'           => 'dashicons-book-alt',
            'show_in_nav_menus'   => false,
            'publicly_queryable'  => true,
            'exclude_from_search' => true,
            'has_archive'         => false,
            'query_var'           => true,
            'can_export'          => true,
            'rewrite'             => true,
            'capability_type'     => 'post',
            'supports'            => array(
                'title'
                )
        );
    
        register_post_type( 'photo_book', $anim_args );
    }

    function loading_scripts_admin($check){
        global $post;
        if ( $check == 'post-new.php' || $check == 'post.php' || 'edit.php') {
            if (isset($post->post_type) && 'photo_book' === $post->post_type) {
                wp_enqueue_media();
                wp_enqueue_style( 'wp-color-picker' );
                wp_enqueue_script( 'photo-book-js-main', plugin_dir_url( __FILE__ ). '/admin/photo.book.js', array('jquery', 'wp-color-picker', 'jquery-ui-sortable'));
                wp_enqueue_style( 'photo-book-css-main', plugin_dir_url( __FILE__ ). '/admin/style.css');
            }
        }
    }

    function books_data_boxes(){
        add_meta_box( 'wcp_photo_book_images', 'Images', array($this, 'render_images_box'), 'photo_book');
        add_meta_box( 'wcp_photo_book_shortcode', 'Shortcode', array($this, 'render_shortcode_box'), 'photo_book', 'side');
        add_meta_box( 'wcp_photo_book_settings', 'Settings', array($this, 'render_settings_box'), 'photo_book');
    }

    function render_shortcode_box(){
        global $post;
        if (isset($post->ID)) {
            echo '[photo-book-gallery id="'.$post->ID.'"]';
        } else {
            echo 'Please Save settings to see shortcode';
        }
    }

    /* Prints the box content */
    function render_images_box() {
        // Use nonce for verification
        wp_nonce_field( plugin_basename( __FILE__ ), 'photo_book_gallery_nonce' );
        include 'render_box_contents.php';
    }

    /* Prints the box content */
    function render_settings_box() {
        global $post; 
        $saved_meta = get_post_meta( $post->ID, 'photo_book_data', true );

        if (isset($saved_meta) && $saved_meta != '') {
            include 'render_settings_box_saved.php';
        } else {
            include 'render_settings_box.php';
        }

    }

    function saving_photo_book_galleries( $post_id ) {
        // verify if this is an auto save routine. 
        // If it is our form has not been submitted, so we dont want to do anything
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) 
            return;

        // verify this came from the our screen and with proper authorization,
        // because save_post can be triggered at other times
        if ( !isset( $_POST['photo_book_gallery_nonce'] ) )
            return;

        if ( !wp_verify_nonce( $_POST['photo_book_gallery_nonce'], plugin_basename( __FILE__ ) ) )
            return;

        // OK, we're authenticated: we need to find and save the data

        // exit();

        update_post_meta($post_id, 'photo_book_data', $_POST['photo_book']);
    }   

    function photo_book_column_head($defaults){
        $defaults['photo_book_col'] = 'Shortcode';
        return $defaults;
    }

    function photo_book_column_content($column_name, $book_id){
        if ($column_name == 'photo_book_col') {
            echo '[photo-book-gallery id="'.$book_id.'"]';
        }
    }

    function render_photo_book_gallery($atts){
        $book_meta = get_post_meta( $atts['id'], 'photo_book_data', true );
        $images_arr = json_decode($book_meta['images']);

        wp_register_script( 'wcp-custom-script', plugins_url( 'js/script.js' , __FILE__ ), array('jquery', 'jquery-ui-core') );

        wp_localize_script( 'wcp-custom-script', 'book', array(
                            //'width' => $data['width'],
                            //'height' => $data['height'],
                            'speedofturn' => $book_meta['speedofturn'],
                            'startingpage' => $book_meta['startingpage'],
                            'readingdirection' => $book_meta['readingdirection'],
                            'pagepadding' => $book_meta['pagepadding'],
                            'pagenumbers' => (isset($book_meta['pagenumbers'])) ? 'true' : '',
                            'closedbook' => (isset($book_meta['closedbook'])) ? 'true' : '',
                            'bottomtoolbar' => (isset($book_meta['bottomtoolbar'])) ? 'true' : '',
                            'zoomonhover' => (isset($book_meta['zoomonhover'])) ? 'true' : '',
                            'autoplay' => (isset($book_meta['autoplay'])) ? 'true' : '',
                            'delay' => $book_meta['bookautoplaydelay'],
                            'manualcontrol' => (isset($book_meta['manualcontrol'])) ? 'true' : '',
                            'keyboardcontrols' => (isset($book_meta['keyboardcontrols'])) ? 'true' : '',
                            'booktabs' => (isset($book_meta['booktabs'])) ? 'true' : '',
                            'bookarrows' => (isset($book_meta['bookarrows'])) ? 'true' : '',
                            'zoomdepth' => (isset($book_meta['zoomdepth'])) ? $book_meta['zoomdepth'] : '1',
                        ));

        wp_enqueue_style( 'book-css', plugins_url( 'css/jquery.booklet.latest.css' , __FILE__ ), array( 'dashicons'));
        wp_enqueue_script( 'easing-js', plugins_url( 'js/jquery.easing.1.3.js' , __FILE__ ), array('jquery') );
        wp_enqueue_script( 'book-js', plugins_url(   'js/jquery.booklet.latest.min.js' , __FILE__ ), array('jquery', 'jquery-ui-core', 'jquery-ui-draggable') );
        if (isset($book_meta['zoomonhover'])) {
            wp_enqueue_script( 'zoom-js', plugins_url( 'js/jquery.zoom.min.js' , __FILE__ ), array('jquery') );
        }

        if (isset($book_meta['enablepopup'])) {
            wp_enqueue_style( 'prettyphoto-css', plugins_url( 'css/prettyPhoto.css' , __FILE__ ));
            wp_enqueue_script( 'pretty-photo', plugins_url( 'js/jquery.prettyPhoto.js' , __FILE__ ), array('jquery') );
        }


        wp_enqueue_script( 'wcp-custom-script');
        $maxwidth = ($book_meta['bookwidth'] != '') ? $book_meta['bookwidth'].'px' : '100%' ;
        ob_start(); ?>

        <div class="wcp-book-cont" style="margin:0 auto; width: 100%; max-width: <?php echo $maxwidth; ?>;">
            <style>
                .b-selector ul, .b-selector ul a, .b-selector .b-current {
                    background-color: <?php echo $book_meta['toolbarbg']; ?>;
                    color: <?php echo $book_meta['toolbarfont']; ?>;
                }
                .popupbutton {
                    position: absolute;
                    top: 0;
                    z-index: 999999999;
                    text-decoration: none;
                    background-color: <?php echo $book_meta['toolbarbg']; ?>;
                    color: <?php echo $book_meta['toolbarfont']; ?>;
                    width: 20px;
                    height: 20px;
                }
                .b-wrap-right .popupbutton {
                    left: 1px;
                }
                .b-wrap-left .popupbutton {
                    right: 1px;
                }
            </style>
            <div class="wcp-loader"></div>
            <div class="flipbook">
                <?php if (isset($images_arr) && $images_arr != '') {
                    foreach ($images_arr as $url) {
                        if (isset($url->image)) { ?>

                            <div title="<?php echo $url->title; ?>" rel="<?php echo $url->chapter; ?>">
                                <?php if (isset($url->purl) && $url->purl != '') { ?>
                                    <a href="<?php echo $url->purl; ?>">
                                <?php } ?>

                                <img src="<?php echo $url->image; ?>">
                                
                                <?php if (isset($url->purl) && $url->purl != '') { ?>
                                </a>
                                <?php } ?>
                                <?php if (isset($book_meta['enablepopup'])) { ?>
                                    <a href="<?php echo $url->image; ?>" rel="prettyPhoto[gall-<?php echo $atts['id']; ?>]" class="popupbutton">
                                        <span class="dashicons dashicons-search"></span>
                                    </a>
                                <?php } ?>
                            </div>

                         <?php } else { ?>


                            <div>
                                <img src="<?php echo $url; ?>">
                                <?php if (isset($book_meta['enablepopup'])) { ?>
                                    <a href="<?php echo $url; ?>" rel="prettyPhoto[gall-<?php echo $atts['id']; ?>]" class="popupbutton">
                                        <span class="dashicons dashicons-search"></span>
                                    </a>
                                <?php } ?>                                
                            </div>


                        <?php }
                    }
                } ?>
            </div>
            <?php if(isset($book_meta['bottomtoolbar'])) { ?>
            <div id="wcp-pagination" style="text-align: center;background-color: <?php echo $book_meta['toolbarbg']; ?>;color: <?php echo $book_meta['toolbarfont']; ?>;">
                <span class="dashicons dashicons-editor-justify" style="position: absolute; top:0; left:0;"></span>
                <span title="<?php _e( 'Previous Page', 'photo-book-gallery' ); ?>" id="wcp-prev" class="dashicons dashicons-arrow-left-alt2"></span>
                <span title="<?php _e( 'Next Page', 'photo-book-gallery' ); ?>" id="wcp-next" class="dashicons dashicons-arrow-right-alt2"></span>
            </div>
            <?php } ?>
        </div>

        <?php return ob_get_clean();
    }
}
?>